@@ -27,22 +27,19 @@
     if (inherits(x, "haven_labelled") || inherits(x, "declared")) {
         return(Recall(unclass(x), each = each))
     }
-    result <- FALSE
+    result <- logical(length(x))
     isna <- is.na(x)
-    x <- asNumeric(x)
-    if (each) {
-        result <- rep(NA, length(x))
-        result[!isna] <- FALSE
-        if (any(!isna)) {
-            x <- x[!isna]
-            result[!isna & !is.na(x)] <- floor(x[!is.na(x)]) == x[!is.na(x)]
+    result[isna] <- NA
+    if (all(isna) || is.logical(x)) {
+        if (each) {
+            return(result)
         }
+        return(FALSE)
+    }
+    x <- asNumeric(x[!isna])
+    result[!isna] <- floor(x) == x
+    if (each) {
         return(result)
     }
-    else {
-        if (all(is.na(x)) || any(!isna & is.na(x))) {
-            return (FALSE)
-        }
-        return(all(floor(x) == x, na.rm = TRUE))
-    }
+    return(all(result[!isna]))
 }
